.. AUTO-GENERATED FILE -- DO NOT EDIT!

torch.lightning
===============

Module: :mod:`torch.lightning`
------------------------------
Inheritance diagram for ``ISLP.torch.lightning``:

.. inheritance-diagram:: ISLP.torch.lightning 
   :parts: 3

.. automodule:: ISLP.torch.lightning

.. currentmodule:: ISLP.torch.lightning

Classes
-------

:class:`ErrorTracker`
~~~~~~~~~~~~~~~~~~~~~


.. autoclass:: ErrorTracker
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

  .. automethod:: __init__

:class:`SimpleDataModule`
~~~~~~~~~~~~~~~~~~~~~~~~~


.. autoclass:: SimpleDataModule
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

  .. automethod:: __init__

:class:`SimpleModule`
~~~~~~~~~~~~~~~~~~~~~


.. autoclass:: SimpleModule
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

  .. automethod:: __init__
